#
# spec file for package git-subrepo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-subrepo
Version:        0.4.6
Release:        bp160.1.8
Summary:        Git Submodule Alternative
License:        MIT
Group:          Development/Tools/Version Control
URL:            https://github.com/ingydotnet/git-subrepo
Source:         https://github.com/ingydotnet/git-subrepo/archive/%{version}.tar.gz
Patch0:         fix-shebangs.patch
BuildRequires:  bash >= 4
BuildRequires:  git-core >= 2.7
BuildRequires:  make
Requires:       bash >= 4
Requires:       git-core >= 2.7
BuildArch:      noarch

%description
This git command "clones" an external git repo into a subdirectory of your
repo. Later on, upstream changes can be pulled in, and local changes can be
pushed back. Simple.

%package bash-completion
Summary:        Bash completion for git-subrepo
Group:          Productivity/File utilities
Requires:       bash-completion
Supplements:    (git-subrepo and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash shell completions for git-subrepo

%package zsh-completion
Summary:        ZSH completion for git-subrepo
Group:          Productivity/File utilities
Supplements:    (git-subrepo and zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for git-subrepo

%prep
%autosetup -p1

%build

%check
# testing needs the source directory to be a git repo
#make test

%install
%make_install PREFIX=%{_prefix} DESTDIR=%{buildroot}

# completions
install -Dm0644 share/completion.bash \
    %{buildroot}%{_datadir}/bash-completion/completions/git-subrepo
install -Dm0644 share/zsh-completion/_git-subrepo \
    %{buildroot}%{_datadir}/zsh/site-functions/_git-subrepo

%files
%license License
%doc Changes ReadMe.pod
%{_libexecdir}/git/%{name}
%{_libexecdir}/git/%{name}.d
%{_mandir}/man1/*

%files bash-completion
%{_datadir}/bash-completion/completions/git-subrepo

%files zsh-completion
%{_datadir}/zsh

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed May 17 2023 Tina Müller <tina.mueller@suse.com>
- Update to 0.4.6:
  * Removes stale worktrees after using the push command
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.5:
  * Add --file option
  * Fix git subrepo status command for subrepos that share a common prefix.
  * Don't allow -b and --all
  * Fix documentation links
  * fix tests to support use of a default branch git config that is not
    "master"
  * pass --force to git add so a user's global .gitignore does not affect
    tests
  * Fix .rc and enable-completion.sh for zsh before 5.1
  * Better format for options
  * The fpath variable is an array; expand correctly
* Tue Nov 24 2020 Tina Müller <tina.mueller@suse.com>
- Update to 0.4.3
  - Remove fix-zsh-completion.patch (not needed anymore)
  - Update fix-shebangs.patch
  - Covert to GitHub Actions for testing
  - Add docker support to test multiple git/bash versions together
  - Require Bash 4.0+
  - Use shellcheck as linter and address issues discovered
  - Discovered bug in git where @ is not a valid workspace name
  - Add --force command to subrepo pull
  - Now works with paths that contain spaces
  - Numerous documentation fixes
  - When two branches pointed to the same commit, we would
    sometimes pick the wrong branch.
  - ZSH completion fixes
  - Allow tests to run outside a git repo
  - Would not work if a different date format was set in git config
  - Address delay in filter-branch on newer versions of git
  - Display the git merge message on merge failure
  - Allow FISH integration on MacOS.
  - Add manpage support for FISH shell
* Thu Jun  4 2020 Tina Müller <tina.mueller@suse.com>
- Remove Recommends bashompletion and fix Supplements
* Thu Jun  4 2020 Tina Müller <tina.mueller@suse.com>
- Add fix-zsh-completion.patch
  See https://github.com/ingydotnet/git-subrepo/pull/476
  Require git > 2.7
* Thu Jun  4 2020 Martin Pluskal <mpluskal@suse.com>
- Cleanup spec file with spec-cleaner
- Drop empty sections
* Wed Jun  3 2020 Tina Müller <tina.mueller@suse.com>
- Initial package 0.4.1
  - --
    version: 0.4.1
    date:    Thu Jan  9 17:11:21 CST 2020
  - Fix Bash version error messages and add to .rc
  - Nicer YAML formatting in .travis.yml
  - Wrap a long line
  - Update the docs
  - Force `make update` to always update docs
  - Don't use XXX in perl stuff
  - Add testing on MacOS
  - Remove conflicting -C from install -d commands.
  - Update version requirement documentation
  - Correct error message in branch
  - Use topo-order in subrepo branch
  - Make “git subrepo clean -f ...” delete refs correctly
  - Fix #410 Push empty repositories with recent git versions
  - Make subrepo work when run in a worktree
  - Simplify finding subrepos
  - Ask git to find the .gitrepo files
  - Doc: fix sentence repetition
  - Fix typos
  - Fixed typo
  - Travis CI not checking out a branch.
  - --
    version: 0.4.0
    date:    Thu Nov  8 12:26:38 CET 2018
    changes:
  - Fix #325 Do not squash main repo commits
  - Improve error message for worktree handling
  - Make version checking portable. #307
  - #307, improve version check
  - #307, update version requirement
  - Fix part #308, Add stderr output if commands fail
  - Fix #306: Add check to prevent following commits with no .gitrepo
  - Remove dry-run flag as it's not implemented. Make sure branch --force delete worktree
  - Fix #296, Replace --first-parent with --ancestry-path
  - Fix #291, specify Trusty host to get new 2.x git
  - Fix #258, add --no-tags to git fetch
  - Test that no remotes are created during clone
  - #257 Remove remote creation to avoid problems with fetch --all
  - (origin/issue/150_to_0.4.0) Fix remove-worktree, remove unused parameters
  - Regenerate completion files
  - filter-branch operation should not be done on HEAD
  - Cleanup push and add hint to push directly after pull
  - Simplify cleanup and add worktree to status
  - Add --method option to init/clone, add a 'config' command
  - Updated unit tests to support the new logic
  - Use 'git worktree' for merge/rebase
  - Update docs to reflect how things should work
  - Make it possible to specify commit messages
  - Redesign, trash the tree hash approach and use merges instead
  - Add release branches to travis-ci
  - Add --method option to init/clone, add a 'config' command
  - Detect multiple pulls, use -u flag to decide
  - Don't reuse previous commit message when using --all
  - Update the docs for pull and push
  - Update error messages when failing merge/rebase
  - Fix env var bug in test/push.t
  - Do not overwrite author information
  - --
    version: 0.3.1
    date:    Tue Jan  3 23:08:56 PST 2017
    changes:
  - Updated release for homebrew
  - Fix #192
  - --
    version: 0.3.0
    date:    Wed Dec  2 19:19:43 PST 2015
    changes:
  - Fix issue #98 and host of others (89, 91, 95, 96)
  - Adds support for the merge-base command
  - Adds stability to many commands
  - Command completion updates
  - Rename `init` to `.rc`
  - @grimmySwe++ @dzzh++ @jrosdahl++ @perlpunk++
  - --
    version: 0.2.3
    date:    Sun Aug  9 13:44:22 PDT 2015
    changes:
  - Fix issues #75 and #76
  - --
    version: 0.2.2
    date:    Wed Jul 22 09:45:13 PDT 2015
    changes:
  - Added the `init` subcommand
  - Applied doc fixes
  - --
    version: 0.2.1
    date:    Sat Mar 28 07:52:22 PDT 2015
    changes:
  - Allows subrepo clone to clone to an empty branch; fixes #26.
  - Refs in status
  - Empty parent set to 'none' in .gitrepo file.
  - Bug fixes
  - --
    version: 0.2.0
    date:    Sat Jan 24 06:22:05 PST 2015
    changes:
  - Massive overhaul
  - .gitrepo files remain the same so backwards compatible
  - Introduce the branch and commit subcommands
  - The checkout subcommand goes away
  - Operations work much smoother like normal Git flow
  - Much more testing
  - Better doc
  - --
    version: 0.1.0
    date:    Fri Feb 21 12:25:53 2014 -0800
    changes:
  - First version
